@@ -1,14 +1,25 @@
-from typing import Any, List, Union
-from pydantic import BaseModel
+from typing import Any, Final, List, Union
 
-INLINE_TOKEN = '__inline__'
+INLINE_TOKEN: Final = "__inline__"
 
 NoneType = type(None)
 
-default_types = {
+
+class undefined:
+    ...
+
+
+class null:
+    ...
+
+
+DEFAULT_TYPES = {
     str(bool): "boolean",
-    str(None): 'void',
-    str(Any): 'any',
+    str(None): "void",
+    str(NoneType): "undefined",
+    str(null): "null",
+    str(undefined): "undefined",
+    str(Any): "any",
     str(int): "number /*int*/",
     str(float): "number /*float*/",
     str(str): "string",
@@ -20,4 +31,4 @@ default_types = {
     str(List[str]): "string[]",
 }
 
-pseudo_classes = Union[dict, None, Any, BaseModel]
+pseudo_classes = Union[dict, None, Any]
