@@ -1,21 +1,29 @@
+from __future__ import annotations
+
 from dataclasses import is_dataclass
 from enum import Enum
+from typing import (TYPE_CHECKING, Any, Dict, List, Literal, Optional, Tuple,
+                    Union, get_type_hints)
+
 from petit_ts.named_types import NamedLiteral, NamedUnion
-from typing import Any, Dict, Literal, Optional, Tuple, Union, get_type_hints
 
 from .ast_utils import get_extended_name
 from .base_handler import BasicHandler, ClassHandler
 from .const import INLINE_TOKEN, NoneType
 
+if TYPE_CHECKING:
+    from .petit_ts import TSTypeStore
+
 
 class UnionHandler(BasicHandler):
     @staticmethod
     def should_handle(cls, store, origin, args) -> bool:
-        return origin is Union or origin is NamedUnion
+        return origin in (NamedUnion, Union)
 
     @staticmethod
     def build(cls: Union[Any], store, origin, args) -> Tuple[Optional[str], str]:
         # Union[Any] because Union is like Never
+
         if (name := get_extended_name(cls)) is None:
             return None, f' | '.join(store.get_repr(arg) for arg in args if arg is not NoneType)
         else:
@@ -25,7 +33,7 @@ class UnionHandler(BasicHandler):
 class LiteralHandler(BasicHandler):
     @staticmethod
     def should_handle(cls, store, origin, args) -> bool:
-        return origin is Literal or origin is NamedLiteral
+        return origin in (Literal, NamedLiteral)
 
     @staticmethod
     def build(cls: Literal, store, origin, args) -> Tuple[Optional[str], str]:
@@ -89,3 +97,16 @@ class DataclassHandler(ClassHandler):
         name = None if cls.__name__.startswith(INLINE_TOKEN) else cls.__name__
         fields = get_type_hints(cls)
         return name, fields
+
+
+class TupleHandler(BasicHandler):
+    @staticmethod
+    def should_handle(cls: Any, store: TSTypeStore, origin: Optional[type], args: List[Any]) -> bool:
+        return origin is tuple
+
+    def build(cls: Any, store: TSTypeStore, origin: Optional[type], args: List[Any]) -> Tuple[Optional[str], Union[str, Dict[str, Any]]]:
+        # Union[Any] because Union is like Never
+        if (name := get_extended_name(cls)) is None:
+            return None, '[' + f', '.join(store.get_repr(arg) for arg in args if arg is not NoneType) + ']'
+        else:
+            return name, f'type {name} = ['+', '.join(store.get_repr(arg) for arg in args) + '];'
